DrynessLevel

Enum DrynessLevel 

#[repr(u8)]
pub enum DrynessLevel { Low = 0, Normal = 1, Extra = 2, Max = 3, }

Variants



Low = 0

Provides a low dryness level for the selected mode



Normal = 1

Provides the normal level of dryness for the selected mode



Extra = 2

Provides an extra dryness level for the selected mode



Max = 3

Provides the max dryness level for the selected mode

Implementations

Source

impl DrynessLevel

pub fn from_u8(value: u8) -> Option<Self>

Convert from u8 value

pub fn to_u8(self) -> u8

Convert to u8 value